From 2965a981b7ec22866fbdf2d567d87e2d068d3617 Mon Sep 17 00:00:00 2001
From: Thomas Bruederli <thomas@roundcube.net>
Date: Fri, 31 Jul 2015 16:04:08 -0400
Subject: [PATCH] Allow to search and import missing PGP pubkeys from keyservers using Publickey.js
---
program/lib/Roundcube/rcube_addressbook.php | 41 +++++++++++++++++++++++++++++------------
1 files changed, 29 insertions(+), 12 deletions(-)
diff --git a/program/lib/Roundcube/rcube_addressbook.php b/program/lib/Roundcube/rcube_addressbook.php
index 7566d65..31189e0 100644
--- a/program/lib/Roundcube/rcube_addressbook.php
+++ b/program/lib/Roundcube/rcube_addressbook.php
@@ -544,13 +544,20 @@
$fn = trim($fn, ', ');
- // fallback to display name
- if (empty($fn) && $contact['name'])
- $fn = $contact['name'];
-
- // fallback to email address
- if (empty($fn) && ($email = self::get_col_values('email', $contact, true)) && !empty($email)) {
- return $email[0];
+ // fallbacks...
+ if ($fn === '') {
+ // ... display name
+ if (!empty($contact['name'])) {
+ $fn = $contact['name'];
+ }
+ // ... organization
+ else if (!empty($contact['organization'])) {
+ $fn = $contact['organization'];
+ }
+ // ... email address
+ else if (($email = self::get_col_values('email', $contact, true)) && !empty($email)) {
+ $fn = $email[0];
+ }
}
return $fn;
@@ -562,29 +569,38 @@
* @param array Hash array with contact data as key-value pairs
* @param string Optional email address
* @param string Optional name (self::compose_list_name() result)
+ * @param string Optional template to use (defaults to the 'contact_search_name' config option)
*
* @return string Display name
*/
- public static function compose_search_name($contact, $email = null, $name = null)
+ public static function compose_search_name($contact, $email = null, $name = null, $templ = null)
{
static $template;
- if (!isset($template)) { // cache this
+ if (empty($templ) && !isset($template)) { // cache this
$template = rcube::get_instance()->config->get('contact_search_name');
if (empty($template)) {
$template = '{name} <{email}>';
}
}
- $result = $template;
+ $result = $templ ?: $template;
if (preg_match_all('/\{[a-z]+\}/', $result, $matches)) {
foreach ($matches[0] as $key) {
- $key = trim($key, '{}');
+ $key = trim($key, '{}');
+ $value = '';
switch ($key) {
case 'name':
$value = $name ?: self::compose_list_name($contact);
+
+ // If name(s) are undefined compose_list_name() may return an email address
+ // here we prevent from returning the same name and email
+ if ($name === $email && strpos($result, '{email}') !== false) {
+ $value = '';
+ }
+
break;
case 'email':
@@ -604,7 +620,8 @@
}
$result = preg_replace('/\s+/', ' ', $result);
- $result = trim($result);
+ $result = preg_replace('/\s*(<>|\(\)|\[\])/', '', $result);
+ $result = trim($result, '/ ');
return $result;
}
--
Gitblit v1.9.1